@@ -116,9 +116,8 @@ void GMXImportExportPluginInterface::exportGMX()
     if (QFileInfo::exists(url.isLocalFile()
                           ? url.toLocalFile() : url.path())) {
         if (url.isLocalFile() && QFileInfo::exists(url.toLocalFile())) {
-            PimCommon::RenameFileDialog::RenameFileDialogResult result = PimCommon::RenameFileDialog::RENAMEFILE_IGNORE;
             PimCommon::RenameFileDialog *dialog = new PimCommon::RenameFileDialog(url, false, parentWidget());
-            result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
+            const PimCommon::RenameFileDialog::RenameFileDialogResult result = static_cast<PimCommon::RenameFileDialog::RenameFileDialogResult>(dialog->exec());
             if (result == PimCommon::RenameFileDialog::RENAMEFILE_RENAME) {
                 url = dialog->newName();
             } else if (result == PimCommon::RenameFileDialog::RENAMEFILE_IGNORE) {
