@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2018-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -204,7 +204,7 @@ void MarkdownInterface::addEmbeddedImages(MessageComposer::TextPart *textPart, Q
     if (!listImage.isEmpty()) {
         listImage.removeDuplicates();
         QStringList imageNameAdded;
-        for (const QString &urlImage : listImage) {
+        for (const QString &urlImage : qAsConst(listImage)) {
             const QUrl url = QUrl::fromUserInput(urlImage);
             if (!url.isLocalFile()) {
                 qCWarning(KMAIL_EDITOR_MARKDOWN_PLUGIN_LOG) << "Url is not a local file " << url;
