@@ -31,7 +31,7 @@ class ConfigDialog : public QDialog
 
 public:
     explicit ConfigDialog(QWidget *parent = nullptr);
-    virtual ~ConfigDialog();
+    ~ConfigDialog() override;
 
 protected:
     void load();
