@@ -22,8 +22,9 @@
 #include "datenums.h"
 #include "configdialog.h"
 
-#include <KCalendarSystem>
+#include <KConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
 Datenums::Datenums()
     : mDisplayedInfo(DayOfYear | DaysRemaining)
@@ -31,7 +32,7 @@ Datenums::Datenums()
     KConfig _config(QStringLiteral("korganizerrc"), KConfig::NoGlobals);
     KConfigGroup config(&_config, "Calendar/Datenums Plugin");
     mDisplayedInfo = (DayNumbers)config.readEntry(
-                         "ShowDayNumbers", int(DayOfYear | DaysRemaining));
+        "ShowDayNumbers", int(DayOfYear | DaysRemaining));
 }
 
 void Datenums::configure(QWidget *parent)
@@ -70,10 +71,10 @@ Element::List Datenums::createDayElements(const QDate &date)
                                     dayOfYear, remainingDays),
                               i18np("1 day since the beginning of the year,\n",
                                     "%1 days since the beginning of the year,\n",
-                                    dayOfYear) +
-                              i18np("1 day until the end of the year",
-                                    "%1 days until the end of the year",
-                                    remainingDays));
+                                    dayOfYear)
+                              +i18np("1 day until the end of the year",
+                                     "%1 days until the end of the year",
+                                     remainingDays));
         break;
     }
     result.append(e);
@@ -81,11 +82,22 @@ Element::List Datenums::createDayElements(const QDate &date)
     return result;
 }
 
+static int weeksInYear(int year)
+{
+    QDate date(year, 12, 31);
+    for (int i = 0; i < 6; ++i) {
+        if (date.weekNumber() > 1) {
+            break;
+        }
+        date = date.addDays(-1);
+    }
+    return date.weekNumber();
+}
+
 Element::List Datenums::createWeekElements(const QDate &date)
 {
     Element::List result;
 
-    const KCalendarSystem *calsys = KLocale::global()->calendar();
     int *yearOfTheWeek = nullptr;
     yearOfTheWeek = nullptr;
     int remainingWeeks;
@@ -100,7 +112,7 @@ Element::List Datenums::createWeekElements(const QDate &date)
     QString weekOfYearAndRemainingWeeksShort;
 
     // Usual case: the week belongs to this year
-    remainingWeeks = calsys->weeksInYear(date.year()) - weekOfYear;
+    remainingWeeks = weeksInYear(date.year()) - weekOfYear;
 
     weekOfYearShort = QString::number(weekOfYear);
     weekOfYearLong = i18nc("Week weekOfYear", "Week %1", weekOfYear);
@@ -109,7 +121,6 @@ Element::List Datenums::createWeekElements(const QDate &date)
                                 weekOfYear);
 
     if (yearOfTheWeek) {    // The week does not belong to this year
-
         weekOfYearShort = i18nc("weekOfYear (year)",
                                 "%1 (%2)", weekOfYear, *yearOfTheWeek);
         weekOfYearLong = i18nc("Week weekOfYear (year)",
@@ -122,10 +133,9 @@ Element::List Datenums::createWeekElements(const QDate &date)
             weekOfYearExtensive = i18np("1 week since the beginning of the year",
                                         "%1 weeks since the beginning of the year",
                                         weekOfYear);
-
         } else {
             // The week belongs to last year
-            remainingWeeks = calsys->weeksInYear(date.year());
+            remainingWeeks = weeksInYear(date.year());
 
             weekOfYearExtensive = i18np("1 week since the beginning of the year",
                                         "%1 weeks since the beginning of the year",
@@ -140,8 +150,8 @@ Element::List Datenums::createWeekElements(const QDate &date)
                                     "%1 weeks until the end of the year",
                                     remainingWeeks);
     weekOfYearAndRemainingWeeksShort = i18nc("weekOfYear / weeksTillEndOfYear",
-                                       "%1 / %2", weekOfYear,
-                                       remainingWeeks);
+                                             "%1 / %2", weekOfYear,
+                                             remainingWeeks);
 
     StoredElement *e = nullptr;
     switch (mDisplayedInfo) {
@@ -167,4 +177,3 @@ Element::List Datenums::createWeekElements(const QDate &date)
 
     return result;
 }
-
