@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,6 +35,8 @@ public:
     void saveSettings();
     void resetSettings();
 private:
+    void readConfig();
+    void writeConfig();
     MessageViewer::DKIMManagerKeyWidget *mManagerKeyWidget = nullptr;
 };
 
