@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@
 #include <QMenuBar>
 #include <QVBoxLayout>
 
-#include <kactioncollection.h>
+#include <KActionCollection>
 #include <QTextEdit>
 #include <KActionMenu>
 #include <messageviewer/headerstrategy.h>
